@@ -433,6 +433,15 @@ class Connection:
         database = database or kwargs.get("db")
         encoding = encoding or kwargs.get("client_encoding")
 
+        # Set these here, to prevent an attribute access error in __del__
+        # in case the connect fails.
+        self.closed = 0
+        self.db = None
+        self.inTransaction = 0
+        self.autocommit = autocommit
+        self.cursors = weakref.WeakValueDictionary()
+        self.rowclass = PgResultSet
+
         self.db = _sqlite.connect(database, mode)
 
         if type(encoding) not in (TupleType, ListType):
@@ -459,14 +468,6 @@ class Connection:
         for typename, conv in converters.items():
             register(typename, conv)
 
-        self.autocommit = autocommit
-
-        self.closed = 0
-        self.inTransaction = 0
-
-        self.cursors = weakref.WeakValueDictionary()
-        self.rowclass = PgResultSet
-
         if timeout is not None:
             self.db.sqlite_busy_timeout(timeout)
 
@@ -543,7 +544,8 @@ class Connection:
         if self.inTransaction:
             self.rollback()
 
-        self.db.close()
+        if self.db:
+            self.db.close()
         self.closed = 1
 
     def cursor(self):
